#!/bin/bash

#
#  usage : clpawsforcestop.sh <sub-command> <option>
# 
#  sub-command :
#         stop <instance-id> <mode>
#         check-stop <instance-id>
#         monitor <instance-id> <mode>
#


export PATH=$PATH:/usr/local/bin

sub_command="$1"


#==================================
# AWS CLIの存在確認
#==================================
which aws > /dev/null 2>&1

if [ $? -ne 0 ]
then
    echo "AWSCLI Was Not Found." 1>&2
    exit 1
fi


#==================================
# AWS CLIで使用する環境変数の設定
#==================================
CURRENT=$(cd $(dirname $0);pwd)

IFS=$'\n'

for ROW in `cat ${CURRENT}/clpaws_setting.conf`
do
    if [[ "${ROW}" =~ "=" && ! "${ROW}" =~ "#" ]]
    then
        LEFT=`expr index "${ROW}" "="`
        LEFT=$((LEFT - 1))
        ENV_NAME="`echo \"${ROW}\" | cut -c -${LEFT}`"
        ENV_NAME="`echo \"${ENV_NAME}\" | sed -e 's/[ \t]*$//'`"
        
        RIGHT=`expr index "${ROW}" "="`
        RIGHT=$((RIGHT + 1))
        ENV_VALUE="`echo \"${ROW}\" | cut -c ${RIGHT}-`"
        ENV_VALUE="`echo \"${ENV_VALUE}\" | sed 's/^[ \t]*//'`"
        
        export "`echo \"${ENV_NAME}\"`"="`echo \"${ENV_VALUE}\"`"
    fi
done

unset IFS


#==================================
# AWS強制停止実行
#==================================
if [ "${sub_command}" == "stop" ]
then

    if [ "$#" -ne 3 ]
    then
        echo "Invalid Option!!" 1>&2
        exit 1
    fi

    instance_id="$2"; mode="$3"

    if [ "${mode}" == "forcestop" ]
    then
        aws ec2 stop-instances --instance-ids "${instance_id}" --force --output text
        if [ $? -ne 0 ]
        then
            echo "Command Error. [aws ec2 stop-instances --force]" 1>&2
            exit 1
        fi
    elif [ "${mode}" == "stop" ]
    then
        aws ec2 stop-instances --instance-ids "${instance_id}" --output text
        if [ $? -ne 0 ]
        then
            echo "Command Error. [aws ec2 stop-instances]" 1>&2
            exit 1
        fi
    elif [ "${mode}" == "reboot" ]
    then
        aws ec2 reboot-instances --instance-ids "${instance_id}" --output text
        if [ $? -ne 0 ]
        then
            echo "Command Error. [aws ec2 reboot-instances]" 1>&2
            exit 1
        fi
    else
        echo "Invalid Parameter!!" 1>&2
        exit 1
    fi


#==================================
# AWS強制停止状態確認
#==================================
elif [ "${sub_command}" == "check-stop" ]
then

    if [ "$#" -ne 2 ]
    then
        echo "Invalid Option!!" 1>&2
        exit 1
    fi

    instance_id="$2"

    check_instance_state="`aws ec2 describe-instances --instance-ids \"${instance_id}\" \
                --filters \"Name=instance-state-name,Values=stopped\" --output text`"
    if [ $? -ne 0 ] || [ -z "${check_instance_state}" ]
    then
        echo "Command Error. [aws ec2 describe-instances(check-stop)]" 1>&2
        exit 1
    fi


#==================================
# AWS強制停止定期確認
#==================================
elif [ "${sub_command}" == "monitor" ]
then

    if [ "$#" -ne 3 ]
    then
        echo "Invalid Option!!" 1>&2
        exit 1
    fi

    instance_id="$2"; mode="$3"
    authmsg_dryrn="DryRunOperation"

    if [ "${mode}" == "stop" ]
    then
        check_dryrun="`aws ec2 stop-instances --instance-ids \"${instance_id}\" --dry-run --output text 2>&1`"
        echo "${check_dryrun}" | grep "${authmsg_dryrn}" > /dev/null 2>&1
        if [ $? -ne 0 ]
        then
            echo "${check_dryrun}" 1>&2
            echo "Command Error. [aws ec2 stop-instances --dry-run]" 1>&2
            exit 1
        fi
    elif [ "${mode}" == "reboot" ]
    then
        check_dryrun="`aws ec2 reboot-instances --instance-ids \"${instance_id}\" --dry-run --output text 2>&1`"
        echo "${check_dryrun}" | grep "${authmsg_dryrn}" > /dev/null 2>&1
        if [ $? -ne 0 ]
        then
            echo "${check_dryrun}" 1>&2
            echo "Command Error. [aws ec2 reboot-instances --dry-run]" 1>&2
            exit 1
        fi
    else
        echo "Invalid Parameter!!" 1>&2
        exit 1
    fi
    
    check_instance_state="`aws ec2 describe-instances --instance-ids \"${instance_id}\"`"
    if [ $? -ne 0 ]
    then
        echo "Command Error. [aws ec2 describe-instances(monitor)]" 1>&2
        exit 1
    fi


#==================================
# サブコマンド不正
#==================================
else
    echo "Invalid Sub Command!!" 1>&2
    exit 1
fi


#==================================
# 正常終了
#==================================
exit 0
