#!/bin/bash

#
#  usage : clpociforcestop.sh <sub-command> <option>
# 
#  sub-command :
#         stop <instance-id> <mode>
#         check-stop <instance-id>
#         monitor <instance-id>
#

sub_command="$1"
OCI_Path="/root/.oci/config"
export PATH=$PATH:/root/bin

#==================================
# OCI強制停止実行
#==================================
if [ "${sub_command}" == "stop" ]
then

	if [ "$#" -ne 3 ]
	then
		echo "Invalid Option!!" 1>&2
		exit 1
	fi

	instance_id="$2"
	mode="$3"

	if [ "${mode}" == "stop" ]
	then
		oci compute instance action --action STOP --instance-id "${instance_id}" --config-file "${OCI_Path}"
		if [ $? -ne 0 ]
		then
			echo "Command Error. [oci compute instance action --action STOP]" 1>&2
			exit 1
		fi
	elif [ "${mode}" == "reboot" ]
	then
		oci compute instance action --action RESET --instance-id "${instance_id}" --config-file "${OCI_Path}"
		if [ $? -ne 0 ]
		then
			echo "Command Error. [oci compute instance action --action RESET]" 1>&2
			exit 1
		fi
	else
		echo "Invalid Parameter!!" 1>&2
		exit 1
	fi


#==================================
# OCI強制停止状態確認
#==================================
elif [ "${sub_command}" == "check-stop" ]
then

	if [ "$#" -ne 2 ]
	then
		echo "Invalid Option!!" 1>&2
		exit 1
	fi

	instance_id="$2"

	CHECK_STATE=`oci compute instance get --instance-id "${instance_id}" --config-file "${OCI_Path}" | grep lifecycle-state | awk -F\" '{print $4}'`
	if [ $? -ne 0 ] || [ "${CHECK_STATE}" != "STOPPED" ]
	then
		echo "Command Error. [oci compute instance get(check-stop)]" 1>&2
		exit 1
	fi


#==================================
# OCI強制停止定期確認
#==================================
elif [ "${sub_command}" == "monitor" ]
then

	if [ "$#" -ne 2 ]
	then
		echo "Invalid Option!!" 1>&2
		exit 1
	fi

	instance_id="$2"

	oci compute instance update --instance-id "${instance_id}" --wait-for-state RUNNING --max-wait-seconds 1 --config-file "${OCI_Path}"
	if [ $? -ne 0 ] && [ $? -ne 2 ]
	then
		echo "Command Error. [oci compute instance update(monitor)]" 1>&2
		exit 1
	fi

	oci compute instance get --instance-id "${instance_id}" --config-file "${OCI_Path}"
	if [ $? -ne 0 ]
	then
		echo "Command Error. [oci compute instance get]" 1>&2
		exit 1
	fi


#==================================
# サブコマンド不正
#==================================
else
	echo "Invalid Sub Command!!" 1>&2
	exit 1
fi


#==================================
# 正常終了
#==================================
exit 0
