#!/bin/sh
#
# Startup script for the CLUSTERPRO trnsv
#

#
# main()
#

# Source function library.
if [ -f /etc/rc.d/init.d/functions ]
then
	. /etc/rc.d/init.d/functions
elif [ -f /etc/rc.status ]
then
	. /etc/rc.status
fi

. /opt/nec/clusterpro/bin/clpfunctions

PATH=/sbin:/bin:/usr/sbin:/usr/bin:/opt/nec/clusterpro/bin
LD_LIBRARY_PATH=/opt/nec/clusterpro/lib
MALLOC_CHECK_=2

export PATH
export LD_LIBRARY_PATH
export MALLOC_CHECK_

# See how we were called.
case "$1" in
  start)
	targetos=`/bin/uname`

	clp_filedel "$1" init_trn $targetos
	clp_logwrite "$1" "clusterpro_trn start process start." init_trn

	#
	cd /opt/nec/clusterpro/bin

	# startupdelay
	startupdelay=`clpcfget -g /root/cluster/startupdelay`
	cfget_ret=$?
	if [ "$cfget_ret" != "0" ]
	then
		startupdelay=0
	fi
	clp_logwrite "$1" "sleeping for "$startupdelay" sec." init_trn
	sleep $startupdelay

	#
	if [ "$targetos" = "SunOS" ]
	then
		echo "Starting clusterpro trnsv: \c"
	else
		logging=`clpcfget -g /root/event/container/logging` 
		cfget_ret=$?
		if [ "$cfget_ret" = "0" -a "$logging" = "1" ]
		then
			echo -n "Starting clusterpro trnsv: " > /dev/null 2>&1
		else
			echo -n "Starting clusterpro trnsv: "
		fi
	fi

	#
	clp_logwrite "$1" "clppidof start." init_trn
	pids=`/opt/nec/clusterpro/bin/clppidof /opt/nec/clusterpro/bin/clpmonp --trnsv 2>&1`
	clp_logwrite "$1" "clppidof end.(pids=${pids})" init_trn

	if [ "$pids" != "" ]
	then
		clp_logwrite "$1" "trnsv already exist." init_trn
		clp_logwrite "$1" "clusterpro_trn start process end." init_trn
		if [ "$cfget_ret" = "0" -a "$logging" = "1" ]
		then
			clp_success $targetos > /dev/null 2>&1
		else
			clp_success $targetos
		fi
		exit 0
	fi

	# starting clusterpro trnsv
	clp_logwrite "$1" "trnsv start process start." init_trn
	./clpmonp --trnsv -a 2 -r 0 -w 0 > /dev/null 2>&1
	monp_ret=$?
	clp_logwrite "$1" "trnsv start process end.("$monp_ret")" init_trn

	if [ "$cfget_ret" = "0" -a "$logging" = "1" ]
	then
		clp_checkerr "$monp_ret" $targetos > /dev/null 2>&1
	else
		clp_checkerr "$monp_ret" $targetos
	fi
	chk_ret=$?
	if [ "$chk_ret" = "1" ]
	then
		clp_logwrite "$1" "clusterpro_trn start process end." init_trn
		exit 0
	fi

	clp_logwrite "$1" "clusterpro_trn start process end." init_trn
	;;
  stop)
	targetos=`/bin/uname`

	clp_filedel "$1" init_trn $targetos
	clp_logwrite "$1" "clusterpro_trn stop process start." init_trn

	#
	if [ "$targetos" = "SunOS" ]
	then
		echo "Shutting down clusterpro trnsv: \c"
	else
		logging=`clpcfget -g /root/event/container/logging` 
		cfget_ret=$?
		if [ "$cfget_ret" = "0" -a "$logging" = "1" ]
		then
			echo -n "Shutting down clusterpro trnsv: " > /dev/null 2>&1
		else
			echo -n "Shutting down clusterpro trnsv: "
		fi
	fi

	#
	cd /opt/nec/clusterpro/bin

	#
	clp_logwrite "$1" "clppidof start." init_trn
	pids=`/opt/nec/clusterpro/bin/clppidof /opt/nec/clusterpro/bin/clpmonp --trnsv 2>&1`
	clp_logwrite "$1" "clppidof end.(pids=${pids})" init_trn

	if [ "$pids" != "" ]
	then
		# shutting down clusterpro trnsv
		clp_logwrite "$1" "trnsv stop process start." init_trn
		if [ "$targetos" = "SunOS" ]
		then
			kill -17 "$pids" 2>/dev/null
			kill_ret=$?
		else
			kill -12 "$pids" 2>/dev/null
			kill_ret=$?
		fi
		clp_logwrite "$1" "trnsv stop process end.("$kill_ret")" init_trn

		i=0
		while [ "$i" -lt "10" ]
		do
			clp_logwrite "$1" "clppidof2 start." init_trn
			pids=`/opt/nec/clusterpro/bin/clppidof /opt/nec/clusterpro/bin/clpmonp --trnsv 2>&1`
			clp_logwrite "$1" "clppidof2 end.(pids=${pids})" init_trn

			if [ "$pids" = "" ]
			then
				clp_logwrite "$1" "trnsv stop success." init_trn
				if [ "$cfget_ret" = "0" -a "$logging" = "1" ]
				then
					clp_success $targetos > /dev/null 2>&1
				else
					clp_success $targetos
				fi

				clp_logwrite "$1" "clusterpro_trn stop process end." init_trn
				exit 0
			fi

			sleep 1
			i=`expr "$i" + 1`
		done

		clp_logwrite "$1" "trnsv stop timeout." init_trn
	else
		clp_logwrite "$1" "trnsv not exist." init_trn
		if [ "$cfget_ret" = "0" -a "$logging" = "1" ]
		then
			clp_success $targetos > /dev/null 2>&1
		else
			clp_success $targetos
		fi

		clp_logwrite "$1" "clusterpro_trn stop process end." init_trn
		exit 0
	fi

	clp_logwrite "$1" "clusterpro_trn stop process end." init_trn
	if [ "$cfget_ret" = "0" -a "$logging" = "1" ]
	then
		clp_success $targetos > /dev/null 2>&1
	else
		clp_success $targetos
	fi
	exit 0
	;;
  restart)
	$0 stop
	if [ "$?" != "0" ]
	then
		exit 1
	fi

	sleep 1
	$0 start
	;;
  status)
	targetos=`/bin/uname`
	if [ "$targetos" = "SunOS" ]
	then
		clp_status_s clptrnsv
	else
		clp_status clptrnsv
	fi
	;;
  *)
	echo "Usage: $0 {start|stop|restart|status}"
	exit 1
	;;
esac

exit 0
